@@ -105,6 +105,15 @@ class Wine:
         3: "native,builtin"
     }
 
+    _reg_types = {
+        0: "REG_SZ",
+        1: "REG_DWORD",
+        2: "REG_MULTI_SZ",
+        3: "REG_BINARY",
+        4: "REG_EXPAND_SZ",
+        5: "REG_NONE",
+    }
+
     def __init__(self, winepath: str, wineprefix: str, verbose: int = 0):
         self._winepath = winepath
         self._wineprefix = wineprefix
@@ -436,7 +445,7 @@ class Wine:
 
         return values
 
-    def reg_add(self, key: str, value: str, data: str):
+    def reg_add(self, key: str, value: str, data: str, data_type: int = 0):
         '''
         Add (or edit) key to the wineprefix register.
 
@@ -448,8 +457,22 @@ class Wine:
             the key value
         data : str
             the data to store in the key value
+        data_type : int
+            the type of data (default 0:REG_SZ):
+            0 (REG_SZ): standard string
+            1 (REG_DWORD): data by a four byte number
+            2 (REG_MULTI_SZ): multiple string
+            3 (REG_BINARY): data as raw binary data
+            4 (REG_EXPAND_SZ): expandable data string
+            5 (REG_NONE): no defined value type
         '''
-        command = f'reg add "{key}" /v "{value}" /d "{data}" /f'
+
+        if data_type not in self._reg_types:
+            raise ValueError("Given key type is not supported.")
+
+        data_type = self._reg_types.get(data_type)
+
+        command = f'reg add "{key}" /v "{value}" /d "{data}" /t "{data_type}" /f'
         self.execute(command=command)
 
     def reg_delete(self, key: str, value: str):
@@ -472,7 +495,7 @@ class Wine:
 
     def set_windows(self, version: str):
         '''
-        Change Windows version of the wineprefix
+        Change Windows version of the wineprefix.
 
         Parameters
         ----------
@@ -527,7 +550,7 @@ class Wine:
 
     def set_virtual_desktop(self, status: bool, res: str = None):
         '''
-        Enable or disable the Wine Virtual Desktop
+        Enable or disable the Wine Virtual Desktop.
 
         Parameters
         ----------
@@ -553,10 +576,113 @@ class Wine:
                 value="Desktop"
             )
 
+    def set_decorations(self, status: bool):
+        '''
+        Enable or disable the windows manager decorations.
+
+        Parameters
+        ----------
+        status : bool
+            the decorations status
+        '''
+        if status:
+            status = "Y"
+        else:
+            status = "N"
+
+        self.reg_add(
+            key="HKEY_CURRENT_USER\\Software\\Wine\\X11 Driver",
+            value="Decorated",
+            data=status
+        )
+
+    def set_window_managed(self, status: bool):
+        '''
+        Enable or disable the windows manager control.
+
+        Parameters
+        ----------
+        status : bool
+            the control status
+        '''
+        if status:
+            status = "Y"
+        else:
+            status = "N"
+
+        self.reg_add(
+            key="HKEY_CURRENT_USER\\Software\\Wine\\X11 Driver",
+            value="Managed",
+            data=status
+        )
+
+    def set_fullscreen_mouse_capture(self, status: bool):
+        '''
+        Enable or disable auto mouse capture in fullscreen.
+
+        Parameters
+        ----------
+        status : bool
+            the capture status
+        '''
+        if status:
+            status = "Y"
+        else:
+            status = "N"
+
+        self.reg_add(
+            key="HKEY_CURRENT_USER\\Software\\Wine\\X11 Driver",
+            value="GrabbFullscreen",
+            data=status
+        )
+
+    def set_dpi(self, dpi: int):
+        '''
+        Set custom DPI value.
+
+        Parameters
+        ----------
+        dpi : int
+            the new density value
+        '''
+        self.reg_add(
+            key="HKEY_CURRENT_USER\\Control Panel\\Desktop",
+            value="LogPixels",
+            data=dpi,
+            data_type=1
+        )
+
     '''
     Wine DLL overrides management
     '''
 
+    def override_dll_list(self):
+        '''
+        List all DLL overrides in the wineprefix
+
+        Return
+        ------
+        list:
+            A list of dll overrides.
+        '''
+        overrides = []
+        values = self.reg_list(
+            "HKEY_CURRENT_USER\\Software\\Wine\\DllOverrides")
+        for v in values:
+            override = [v[0]]
+            if v[2] == "native,builtin":
+                override.append(3)
+            elif v[2] == "builtin,native":
+                override.append(2)
+            elif v[2] == "native":
+                override.append(1)
+            elif v[2] == "builtin":
+                override.append(0)
+
+            overrides.append(override)
+
+        return overrides
+
     def override_dll(self, name: str, override: int = 0, restore: bool = False):
         '''
         Overriding a DLL in the wineprefix.
